@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,6 +68,7 @@ import com.openexchange.mail.api.IMailProperties;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.api.MailLogicTools;
+import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mailaccount.MailAccountStorageService;
@@ -216,8 +217,7 @@ public final class POP3Access extends MailAccess<POP3FolderStorage, POP3MessageS
              */
             String providerName = POP3StorageUtil.getPOP3StorageProviderName(pop3Access.accountId, user, cid);
             if (null == providerName) {
-                final OXException e =
-                    POP3ExceptionCode.MISSING_POP3_STORAGE_NAME.create(Integer.valueOf(user), Integer.valueOf(cid));
+                OXException e = POP3ExceptionCode.MISSING_POP3_STORAGE_NAME.create(Integer.valueOf(user), Integer.valueOf(cid));
                 LOG.debug("Using fallback storage \"mailaccount\".", e);
                 providerName = MailAccountPOP3StorageProvider.NAME;
                 /*
@@ -383,34 +383,28 @@ public final class POP3Access extends MailAccess<POP3FolderStorage, POP3MessageS
 
     @Override
     public boolean ping() throws OXException {
-        /*-
-         * Some POP3 accounts specify a connect frequency limitation,
-         * therefore skip ping check if:
-         *
-         * com.openexchange.pop3.allowPing=false
-         */
-        final ConfigurationService service = POP3ServiceRegistry.getServiceRegistry().getService(ConfigurationService.class);
-        if (null == service || !service.getBoolProperty("com.openexchange.pop3.allowPing", false)) {
-            if (null == service || service.getBoolProperty("com.openexchange.pop3.logDeniedPing", true)) {
-                warnings.add(POP3ExceptionCode.VALIDATE_DENIED.create());
-            }
-            return true;
-        }
-        /*
-         * Ping allowed by configuration service
-         */
         final POP3Config config = getPOP3Config();
         checkFieldsBeforeConnect(config);
+        POP3Store pop3Store = null;
         try {
-            final POP3Store pop3Store = POP3StoreConnector.getPOP3Store(config, getMailProperties(), false, session, false).getPop3Store();
-            /*
-             * Close quietly
+            /*-
+             * Some POP3 accounts specify a connect frequency limitation,
+             * therefore skip ping check if:
+             *
+             * com.openexchange.pop3.allowPing=false
              */
-            try {
-                pop3Store.close();
-            } catch (final MessagingException e) {
-                LOG.warn("", e);
+            final ConfigurationService service = POP3ServiceRegistry.getServiceRegistry().getService(ConfigurationService.class);
+            if (null == service || !service.getBoolProperty("com.openexchange.pop3.allowPing", false)) {
+                if (null == service || service.getBoolProperty("com.openexchange.pop3.logDeniedPing", true)) {
+                    warnings.add(POP3ExceptionCode.VALIDATE_DENIED.create());
+                }
+                return true;
             }
+            closeQuietly(pop3Store);
+            /*
+             * Try to authenticate
+             */
+            pop3Store = POP3StoreConnector.getPOP3Store(config, getMailProperties(), false, session, false, MailProperties.getInstance().isEnforceSecureConnection()).getPop3Store();
             /*
              * Add warning if non-secure
              */
@@ -427,6 +421,11 @@ public final class POP3Access extends MailAccess<POP3FolderStorage, POP3MessageS
             }
         } catch (final OXException e) {
             throw e;
+        } finally {
+            /*
+             * Close quietly
+             */
+            closeQuietly(pop3Store);
         }
         return true;
     }
@@ -576,4 +575,14 @@ public final class POP3Access extends MailAccess<POP3FolderStorage, POP3MessageS
         }
     }
 
+    private static void closeQuietly(POP3Store pop3Store) {
+        if (null != pop3Store) {
+            try {
+                pop3Store.close();
+            } catch (final MessagingException e) {
+                LOG.warn("", e);
+            }
+        }
+    }
+
 }
