@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,6 @@ import java.util.Dictionary;
 import java.util.Hashtable;
 import org.osgi.framework.BundleActivator;
 import com.openexchange.caching.CacheService;
-import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
@@ -93,9 +92,7 @@ public final class POP3Activator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
-            ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class,
-            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class
-        };
+            ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class, ContextService.class, TimerService.class, ConfigViewFactory.class  };
     }
 
     @Override
@@ -127,13 +124,9 @@ public final class POP3Activator extends HousekeepingActivator {
                     }
                 }
             }
-            final Dictionary<String, String> dictionary = new Hashtable<String, String>(2);
+            final Dictionary<String, String> dictionary = new Hashtable<String, String>();
             dictionary.put("protocol", POP3Provider.PROTOCOL_POP3.toString());
             registerService(MailProvider.class, POP3Provider.getInstance(), dictionary);
-            /*
-             * Signal availability for POP3 provider
-             */
-            getService(CapabilityService.class).declareCapability("pop3");
             /*
              * Add built-in mail account POP3 storage provider
              */
@@ -170,10 +163,6 @@ public final class POP3Activator extends HousekeepingActivator {
                 customizer.dropAllRegistrations();
                 this.customizer = null;
             }
-            CapabilityService capabilityService = getService(CapabilityService.class);
-            if (null != capabilityService) {
-                capabilityService.undeclareCapability("pop3");
-            }
             cleanUp();
             /*
              * Clear service registry
