@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,6 @@ import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
-import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -81,6 +80,7 @@ import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.MailAccess;
+import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailFolderDescription;
 import com.openexchange.mail.dataobjects.MailMessage;
@@ -148,7 +148,9 @@ public class MailAccountPOP3Storage implements POP3Storage {
                 // Try to compose path
                 tmp = composeUniquePath(pop3Access.getAccountId(), session.getUserId(), session.getContextId());
                 // Add to properties
-                properties.addProperty(POP3StoragePropertyNames.PROPERTY_PATH, tmp);
+                if (!"validate".equals(session.getParameter("mail-account.request"))) {
+                    properties.addProperty(POP3StoragePropertyNames.PROPERTY_PATH, tmp);
+                }
             }
             path = tmp;
         }
@@ -336,11 +338,11 @@ public class MailAccountPOP3Storage implements POP3Storage {
             defaultMailAccess.connect(false);
             // Check path existence
             final IMailFolderStorage fs = defaultMailAccess.getFolderStorage();
-            if (!fs.exists(path)) {
+            Session session = pop3Access.getSession();
+            if (!"validate".equals(session.getParameter("mail-account.request")) && !fs.exists(path)) {
                 final MailFolderDescription toCreate = new MailFolderDescription();
 
                 final MailPermission mp = new DefaultMailPermission();
-                final Session session = pop3Access.getSession();
                 mp.setEntity(session.getUserId());
 
                 toCreate.addPermission(mp);
@@ -562,11 +564,18 @@ public class MailAccountPOP3Storage implements POP3Storage {
         // Start sync process
         POP3Store pop3Store = null;
         try {
-            final POP3StoreResult result = POP3StoreConnector.getPOP3Store(pop3Access.getPOP3Config(), pop3Access.getMailProperties(), false, session, !expunge);
+            final POP3StoreResult result = POP3StoreConnector.getPOP3Store(pop3Access.getPOP3Config(), pop3Access.getMailProperties(), false, session, !expunge, pop3AccountId > 0 && MailProperties.getInstance().isEnforceSecureConnection());
             pop3Store = result.getPop3Store();
-            final boolean containsWarnings = result.containsWarnings();
-            if (containsWarnings) {
-                warnings.addAll(result.getWarnings());
+            boolean uidlNotSupported = false;
+            if (result.containsWarnings()) {
+                final Collection<OXException> warns = result.getWarnings();
+                warnings.addAll(warns);
+                for (final OXException warning : warns) {
+                    if (POP3ExceptionCode.EXPUNGE_MODE_ONLY.equals(warning)) {
+                        uidlNotSupported = true;
+                        break;
+                    }
+                }
             }
             /*
              * Increase counter
@@ -617,7 +626,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
                     }
                     int start = 1;
                     while (start <= messageCount) {
-                        final int num = add2Storage(inbox, start, blockSize, containsWarnings, messageCount, seqnum2uidl);
+                        final int num = add2Storage(inbox, start, blockSize, uidlNotSupported, messageCount, seqnum2uidl);
                         start += num;
                         messageCache.clear();
                         messageCache.setSize(messageCount);
@@ -625,7 +634,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
                     /*
                      * Expunge if necessary
                      */
-                    if (containsWarnings || expunge) {
+                    if (uidlNotSupported || expunge) {
                         /*
                          * Expunge all messages
                          */
@@ -792,7 +801,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
         return null == property ? false : Boolean.parseBoolean(property.trim());
     }
 
-    private int add2Storage(final POP3Folder inbox, final int start, final int len, final boolean containsWarnings, final int messageCount, final TIntObjectMap<String> seqnum2uidl) throws MessagingException, OXException {
+    private int add2Storage(final POP3Folder inbox, final int start, final int len, final boolean uidlNotSupported, final int messageCount, final TIntObjectMap<String> seqnum2uidl) throws MessagingException, OXException {
         final int retval; // The number of messages added to storage
         final int end; // The ending sequence number (inclusive)
         {
@@ -809,7 +818,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
         /*
          * Check for possible warnings. If so append messages to storage without filtering new messages.
          */
-        if (containsWarnings) {
+        if (uidlNotSupported) {
             /*
              * Append messages to storage
              */
